# Location

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**array_positions** | [**ArrayPositions**](ArrayPositions.md) |  | [optional] 
**end** | **int** |  | [optional] 
**pos** | **int** | Pos is the position of the term within the field, starting at 1 | [optional] 
**start** | **int** | Start and End are the byte offsets of the term in the field | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


